package com.jorgecastillo.kanadrill;

import android.annotation.TargetApi;
import android.content.Context;
import android.content.res.Configuration;
import android.os.Build;
import android.os.Bundle;
import android.preference.ListPreference;
import android.preference.Preference;
import android.preference.PreferenceActivity;
import android.preference.PreferenceFragment;
import android.preference.PreferenceManager;

import java.util.List;

public class SettingsActivity extends PreferenceActivity {

  private static final boolean ALWAYS_SIMPLE_PREFS = false;

  @Override
  protected void onCreate(Bundle savedInstanceState) {
    int theme_list = CommonCode.theme_list;
    if (theme_list == 1) {
      setTheme(R.style.HoloLight);
    } else if (theme_list == 2) {
      setTheme(R.style.HoloDark);
    } else if (theme_list == 3) {
      setTheme(R.style.MaterialLight);
    } else if (theme_list == 4) {
      setTheme(R.style.MaterialDark);
    }
    super.onCreate(savedInstanceState);
  }

  @Override
  protected void onPostCreate(Bundle savedInstanceState) {
    super.onPostCreate(savedInstanceState);

    setupSimplePreferencesScreen();
  }

  @SuppressWarnings("deprecation")
  private void setupSimplePreferencesScreen() {
    if (!isSimplePreferences(this)) {
      return;
    }

    addPreferencesFromResource(R.xml.pref_general);

  }

  @Override
  public boolean onIsMultiPane() {
    return isXLargeTablet(this) && !isSimplePreferences(this);
  }

  private static boolean isXLargeTablet(Context context) {
    return (context.getResources().getConfiguration().screenLayout &
        Configuration.SCREENLAYOUT_SIZE_MASK)
        >= Configuration.SCREENLAYOUT_SIZE_XLARGE;
  }

  private static boolean isSimplePreferences(Context context) {
    return ALWAYS_SIMPLE_PREFS
        || Build.VERSION.SDK_INT < Build.VERSION_CODES.HONEYCOMB
        || !isXLargeTablet(context);
  }

  @Override
  @TargetApi(Build.VERSION_CODES.HONEYCOMB)
  public void onBuildHeaders(List<Header> target) {
    if (!isSimplePreferences(this)) {
      loadHeadersFromResource(R.xml.pref_headers, target);
    }
  }

  private static Preference.OnPreferenceChangeListener
      sBindPreferenceSummaryToValueListener =
      new Preference.OnPreferenceChangeListener() {
        @Override
        public boolean onPreferenceChange(Preference preference, Object value) {
          String stringValue = value.toString();

          if (preference instanceof ListPreference) {
            // For list preferences, look up the correct display value in
            // the preference's 'entries' list.
            ListPreference listPreference = (ListPreference) preference;
            int index = listPreference.findIndexOfValue(stringValue);

            // Set the summary to reflect the new value.
            preference
                .setSummary(index >= 0 ?
                    listPreference.getEntries()[index]
                    : null);

          } else {
            // For all other preferences, set the summary to the value's
            // simple string representation.
            preference.setSummary(stringValue);
          }
          return true;
        }
      };

  private static void bindPreferenceSummaryToValue(Preference preference) {
    // Set the listener to watch for value changes.
    preference
        .setOnPreferenceChangeListener(sBindPreferenceSummaryToValueListener);

    // Trigger the listener immediately with the preference's
    // current value.
    sBindPreferenceSummaryToValueListener.onPreferenceChange(
        preference,
        PreferenceManager.getDefaultSharedPreferences(
            preference.getContext()).getString(preference.getKey(),
            ""));
  }

  @TargetApi(Build.VERSION_CODES.HONEYCOMB)
  public static class GeneralPreferenceFragment extends PreferenceFragment {
    @Override
    public void onCreate(Bundle savedInstanceState) {
      super.onCreate(savedInstanceState);
      addPreferencesFromResource(R.xml.pref_general);

      // Bind the summaries of EditText/List/Dialog/Ringtone preferences
      // to their values. When their values change, their summaries are
      // updated to reflect the new value, per the Android Design
      // guidelines.
      bindPreferenceSummaryToValue(findPreference("kana_list"));
      bindPreferenceSummaryToValue(findPreference("order_list"));
      bindPreferenceSummaryToValue(findPreference("theme_list"));
      bindPreferenceSummaryToValue(findPreference("autoforward_speed"));
    }
  }

}
